pub struct ProxyEvent { /* private fields */ }Expand description
A sendable event payload used by context proxies to forward events from non-UI threads.
Implementations
Sourceimpl ProxyEvent
impl ProxyEvent
Sourcepub fn propagate(self, propagation: Propagation) -> Self
pub fn propagate(self, propagation: Propagation) -> Self
Sets the propagation of the event.
Sourcepub fn into_event(self) -> Event
pub fn into_event(self) -> Event
Converts a proxy event into a normal event on the UI thread.